@@ -113,7 +113,8 @@ def register_config():
         print '>>> Congrts! You have successfully setup the configuration.\n\n' 
       else:
         print '>>> Oops, You are not able to Autheticate.'
-  with open(CONFIG_FILE_LOC, 'wb') as configfile:
+  #with open(CONFIG_FILE_LOC, 'wb') as configfile:
+  with os.fdopen(os.open(CONFIG_FILE_LOC, os.O_WRONLY | os.O_CREAT, 0777), 'wb') as configfile:
     Config.write(configfile)
   
   #print '>>> Info Successfully Saved.'
